@@ -9,10 +9,10 @@ my $dirlist = ['d:/My Music/', 'c:/mp3/'];
 #
 $dbh->func( {data_type=>'MP3',dirs=>$dirlist},'import' );
 my $sth = $dbh->prepare(q{
-    SELECT song_name,genre FROM table1 WHERE year = '1999'
+    SELECT artist,song_name FROM table1
 });
 $sth->execute;
 while( my($name,$genre) = $sth->fetchrow_array ) {
-    printf "%25s : %s\n", $genre, $name if $name;
+    printf "%40s : %s\n", $genre, $name if $name;
 }
 __END__
